<?php

namespace Teknisa\FIN\Modules\ContaPagar\Services\Retorno;

abstract class RetornoFactory{

    CONST CODIGO_COMPENSACAO_SANTANDER = "033";
    CONST CODIGO_COMPENSACAO_BRADESCO  = "237";
    CONST CODIGO_COMPENSACAO_ITAU      = "341";
    CONST CODIGO_COMPENSACAO_CAIXAEF   = "104";
    CONST CODIGO_COMPENSACAO_BRASIL    = "001";
    CONST CODIGO_COMPENSACAO_SICOOB    = "756";
    CONST CODIGO_COMPENSACAO_SICREDI   = "748";

    CONST LAYOUT_PAGFORN_BRADESCO  = 1;
    CONST LAYOUT_MULTIPAG_BRADESCO = 2;
    CONST LAYOUT_SISPAG_ITAU       = 1;
    CONST LAYOUT_RISCOSACADA_ITAU  = 2;

    public static function getBancoCnab($cdempresa, $cdbanco, $arquivo, $layout = false)
    {
        try
        {
            if ($cdbanco === self::CODIGO_COMPENSACAO_SANTANDER){
                return new LeitorCnabSantander($arquivo, $cdempresa, $cdbanco);
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_BRADESCO){
                if ($layout == self::LAYOUT_PAGFORN_BRADESCO || is_null($layout)){
                    return new PagFornBradesco($arquivo, $cdempresa, $cdbanco);
                }elseif($layout == self::LAYOUT_MULTIPAG_BRADESCO){
                    return new MultiPagBradesco($arquivo, $cdempresa, $cdbanco);
                }
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_ITAU){
                if ($layout == self::LAYOUT_SISPAG_ITAU || is_null($layout)){
                    return new LeitorCnabItau($arquivo, $cdempresa, $cdbanco);
                }elseif($layout == self::LAYOUT_RISCOSACADA_ITAU){
                    return new RiscoSacadaCnabItau($arquivo, $cdempresa, $cdbanco);
                }
                return new LeitorCnabItau($arquivo, $cdempresa, $cdbanco);
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_CAIXAEF){
                return new LeitorCnabCaixa($arquivo, $cdempresa, $cdbanco);
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_BRASIL){
                return new LeitorCnabBrasil($arquivo, $cdempresa, $cdbanco);
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_SICOOB){
                return new LeitorCnabSicoob($arquivo, $cdempresa, $cdbanco);
            }
            elseif($cdbanco == self::CODIGO_COMPENSACAO_SICREDI){
                return new LeitorCnabSicredi($arquivo, $cdempresa, $cdbanco);
            }
            else throw new \Exception('O Códido de Compensação informado não pertece a nenhum banco reconhecido.');

        } catch (\Exception $e) {
            throw $e;
        }
    }
}